<?php

namespace App\Http\Controllers\Admin;

use App\Departments;
use App\Tickets;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\User;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Auth;

class SearchController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function search(Request $request){
        $tickets = Tickets::where('subject', 'LIKE', '%' . $request->q . '%')->orderBy('created_at', 'desc')->where(function($query){
            $query->where('assigned_to', Auth::id())->orWhere('user_id', Auth::id());
        })->paginate(10);

        $search_term = $request->q;

        $users = User::all();
        $open = Tickets::where(['assigned_to'=> Auth::id(), 'status' => 'ouverte'])->count() + Tickets::where(['user_id'=> Auth::id(), 'status' => 'ouverte'])->count();
        $replied = Tickets::where(['assigned_to'=> Auth::id(), 'replayed' => 1])->count() + Tickets::where(['user_id'=> Auth::id(), 'replayed' => 1])->count();
        $closed = Tickets::where(['assigned_to'=> Auth::id(), 'status' => 'terminée'])->count() + Tickets::where(['user_id'=> Auth::id(), 'status' => 'terminée'])->count();
        $pending = Tickets::where(['assigned_to'=> Auth::id(), 'status' => 'en cours'])->count() + Tickets::where(['user_id'=> Auth::id(), 'status' => 'en cours'])->count();

        $departments = Departments::all();
        $tickets_depart = Tickets::where('assigned_to', Auth::id())->orWhere('user_id', Auth::id())->get();

        //dd($open);
         return view('admin.tickets.index', compact('tickets', 'search_term', 'open','replied', 'closed', 'pending', 'departments', 'tickets_depart', 'users'));
    }


    public function status($status){
        if($status == 'a répondu'){
            $tickets = Tickets::where('replayed', 1)->orderBy('created_at', 'desc')->where(function($query){
                $query->where('assigned_to', Auth::id())->orWhere('user_id', Auth::id());
            })->paginate(10);
        }else{
            $tickets = Tickets::where('status', $status)->orderBy('created_at', 'desc')->where(function($query){
                $query->where('assigned_to', Auth::id())->orWhere('user_id', Auth::id());
            })->paginate(10);
        }

        //dd($tickets[0]->users->name);
        $users = User::all();
        $open = Tickets::where(['assigned_to'=> Auth::id(), 'status' => 'ouverte'])->count() + Tickets::where(['user_id'=> Auth::id(), 'status' => 'ouverte'])->count();
        $replied = Tickets::where(['assigned_to'=> Auth::id(), 'replayed' => 1])->count() + Tickets::where(['user_id'=> Auth::id(), 'replayed' => 1])->count();
        $closed = Tickets::where(['assigned_to'=> Auth::id(), 'status' => 'terminée'])->count() + Tickets::where(['user_id'=> Auth::id(), 'status' => 'terminée'])->count();
        $pending = Tickets::where(['assigned_to'=> Auth::id(), 'status' => 'en cours'])->count() + Tickets::where(['user_id'=> Auth::id(), 'status' => 'en cours'])->count();


        $departments = Departments::all();
        $tickets_depart = Tickets::where('assigned_to', Auth::id())->orWhere('user_id', Auth::id())->get();

        return view('admin.tickets.index', compact('tickets', 'open','replied', 'closed', 'pending', 'departments', 'tickets_depart', 'users'));

    }

    public function statusLiees($status){
        $liees = true;
        if($status == 'a répondu'){
            $tickets = Tickets::join('ticket_users', 'ticket_users.ticket_id', '=', 'tickets.id')
            ->join('users', 'users.id', '=', 'ticket_users.user_id')
            ->where('ticket_users.user_id', Auth::id())
            ->where('tickets.replayed', 1)
            ->orderBy('created_at', 'desc')
            ->select( 'tickets.*')
            ->paginate(10);
        }else{
            $tickets = Tickets::join('ticket_users', 'ticket_users.ticket_id', '=', 'tickets.id')
            ->join('users', 'users.id', '=', 'ticket_users.user_id')
            ->where('ticket_users.user_id', Auth::id())
            ->where('tickets.status', $status)
            ->orderBy('created_at', 'desc')
            ->select( 'tickets.*')
            ->paginate(10);
        }

        $users = User::all();
        $open = Tickets::join('ticket_users', 'ticket_users.ticket_id', '=', 'tickets.id')
            ->join('users', 'users.id', '=', 'ticket_users.user_id')
            ->where('ticket_users.user_id', Auth::id())->where(['status' => 'ouverte'])->count();
        $replied = Tickets::join('ticket_users', 'ticket_users.ticket_id', '=', 'tickets.id')
            ->join('users', 'users.id', '=', 'ticket_users.user_id')
            ->where('ticket_users.user_id', Auth::id())->where(['replayed' => 1])->count();
        $closed = Tickets::join('ticket_users', 'ticket_users.ticket_id', '=', 'tickets.id')
            ->join('users', 'users.id', '=', 'ticket_users.user_id')
            ->where('ticket_users.user_id', Auth::id())->where(['status' => 'terminée'])->count();
        $pending = Tickets::join('ticket_users', 'ticket_users.ticket_id', '=', 'tickets.id')
            ->join('users', 'users.id', '=', 'ticket_users.user_id')
            ->where('ticket_users.user_id', Auth::id())->where('status', 'en cours')->count();

        $departments = Departments::all();
        $tickets_depart = Tickets::join('ticket_users', 'ticket_users.ticket_id', '=', 'tickets.id')
            ->join('users', 'users.id', '=', 'ticket_users.user_id')
            ->where('ticket_users.user_id', Auth::id())->get();

        return view('admin.tickets.index', compact('tickets', 'open','replied', 'closed', 'pending', 'departments', 'tickets_depart', 'users', 'liees'));

    }


    public function department($id){

        //$tickets = Tickets::where('department_id', $id)->paginate(15);
        //$users = User::where('department_id', $id)->get();
        
        /*$tickets = DB::table('tickets')
            ->join('users', 'users.id', '=', 'tickets.assigned_to')
            ->join('departments', 'departments.id', '=', 'users.department_id')
            ->select( 'tickets.*')
            ->where('users.department_id', $id)
            ->orderBy('created_at', 'desc')
            ->paginate(10);
        */

        $tickets = Tickets::join('users', 'users.id', '=', 'tickets.assigned_to')
            ->join('departments', 'departments.id', '=', 'users.department_id')
            ->where('users.department_id', $id)
            ->where('tickets.user_id', Auth::id())
            ->orderBy('created_at', 'desc')
            ->select( 'tickets.*')
            ->paginate(10);
        //$tickets = Tickets::where('user_id', 1)->paginate(15);
        //dd($tickets);
       
        $users = User::all();

        $open = Tickets::where(['assigned_to'=> Auth::id(), 'status' => 'ouverte'])->count() + Tickets::where(['user_id'=> Auth::id(), 'status' => 'ouverte'])->count();
        $replied = Tickets::where(['assigned_to'=> Auth::id(), 'replayed' => 1])->count() + Tickets::where(['user_id'=> Auth::id(), 'replayed' => 1])->count();
        $closed = Tickets::where(['assigned_to'=> Auth::id(), 'status' => 'terminée'])->count() + Tickets::where(['user_id'=> Auth::id(), 'status' => 'terminée'])->count();
        $pending = Tickets::where(['assigned_to'=> Auth::id(), 'status' => 'en cours'])->count() + Tickets::where(['user_id'=> Auth::id(), 'status' => 'en cours'])->count();


        $departments = Departments::all();
        $tickets_depart = Tickets::where('assigned_to', Auth::id())->orWhere('user_id', Auth::id())->get();

        return view('admin.tickets.index', compact('tickets', 'open','replied', 'closed', 'pending', 'departments', 'tickets_depart', 'users'));

    }
    


}
