<?php

namespace App\Http\Controllers\Admin;

if (version_compare(PHP_VERSION, '7.2.0', '>=')) {
    // Ignores notices and reports all other kinds... and warnings
    error_reporting(E_ALL ^ E_NOTICE ^ E_WARNING);
    // error_reporting(E_ALL ^ E_WARNING); // Maybe this is enough
}

use App\Departments;
use App\Role;
use App\User;
use App\Tickets;
use App\Files;
use App\Replies;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\TicketUser;
use Illuminate\Support\Facades\Auth;

class StaffController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $users = User::paginate(10);
        //dd($users);
        return view('admin.staff.index',compact('users'));
    }

    /**
     * Create new resource.
     */
    public function create(){
        if(!Auth::user()->hasRole('admin')){
            return redirect::to('admin/tickets');
        }
        $departments = Departments::all();
        return view('admin.staff.add',compact('departments'));
    }


    /**
     * Add new resource to database.
     */
    public function store(Request $request)
    {
        if(!Auth::user()->hasRole('admin')){
            return redirect::to('admin/tickets');
        }
        $this->validate($request, [
            'name' => 'required|max:32',
            'username' => 'required|regex:/^[A-Za-z.-]+$/|max:100|unique:users',
            'email' => 'required|email|max:100|unique:users',
            'password' => 'required|min:6',
            'department_id' => 'required',
            'file' =>'mimes:jpg,jpeg,png',
        ]);
        $user  = new User();
        $user->name = $request->name;
        $user->username = $request->username;
        $user->email = $request->email;
        $user->password = bcrypt($request->password);
        $user->department_id = $request->department_id;

        if(!empty($request->file)){
            $request->file->move('uploads', $request->file->getClientOriginalName());
            $user->avatar = $request->file->getClientOriginalName();
        }
        $user->save();
        $role = Role::where('name', 'staff')->first();
        $user->roles()->attach($role->id);
        return redirect::to('admin/staff')->withMessage('Utilisateur ajouté');
    }


    /**
     * Show the form for editing the specified resource.
     */
    public function edit($id)
    {
        if(!Auth::user()->hasRole('admin')){
            return redirect::to('admin/tickets');
        }
        $user = User::find($id);
        $users = User::all();
        $departments = Departments::all();
        return view('admin.staff.edit', compact('user', 'departments', 'users'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, $id)
    { 
        if(!Auth::user()->hasRole('admin')){
            return redirect::to('admin/tickets');
        }
        $this->validate($request, [
            'name' => 'required|max:32',
            'username' => 'required|regex:/^[A-Za-z.-]+$/|max:100|unique:users,username,'.$id,
            'email' => 'email|max:40|unique:users,email,'.$id,
            'department_id' => 'required',
            'file' =>'mimes:jpg,jpeg,png',
        ]);


        $user = User::find($id);
        $user->name = $request->name;
        $user->username = $request->username;
        $user->email = $request->email;
        $user->department_id = $request->department_id;
        if($request->has('role')){
            $user->data = json_encode($request->data);
            
            $role = Role::where('name', 'vice-president')->first();
            $user->detachRoles($user->roles);
            $user->roles()->attach($role->id);
        }else{
            $user->data = "";
            $role = Role::where('name', 'staff')->first();
            $user->detachRoles($user->roles);
            $user->roles()->attach($role->id);
        }

        $user->save();

        if(!empty($request->file)){
            $request->file->move('uploads', $request->file->getClientOriginalName());
            $user->avatar = $request->file->getClientOriginalName();
        }



        if($request->role == 'admin'){
            $role = Role::where('name', 'admin')->first();
            $user->detachRoles($user->roles);
            $user->roles()->attach($role->id);
        }
        if($request->role == 'staff'){
            $role = Role::where('name', 'staff')->first();
            $user->detachRoles($user->roles);
            $user->roles()->attach($role->id);

        }



        return redirect::to('admin/staff')->withMessage("L'enregistrement a été mis à jour");
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy($id)
    {
        if(!Auth::user()->hasRole('admin')){
            return redirect::to('admin/tickets');
        }
        $tickets = Tickets::where('user_id', $id)->get();
        foreach ($tickets as $ticket){
            $files = Files::where('ticket_id' , $ticket->id)->get();
            foreach ($files as $file){
                Storage::delete($file->name);
            }
            Replies::where('ticket_id', $ticket->id)->delete();
            Files::where('ticket_id', $ticket->id)->delete();
        }
        Tickets::where('user_id', $id)->delete();
        TicketUser::where('user_id', $id)->delete();
        User::find($id)->delete();
        return 'success';
    }
}
