<?php

namespace App\Http\Controllers\Admin;

if (version_compare(PHP_VERSION, '7.2.0', '>=')) {
    // Ignores notices and reports all other kinds... and warnings
    error_reporting(E_ALL ^ E_NOTICE ^ E_WARNING);
    // error_reporting(E_ALL ^ E_WARNING); // Maybe this is enough
}

use App\Notifications\NewTicket;
use App\Notifications\TicketReply;
use App\Notifications\TicketStatus;
use App\Replies;
use App\Settings;
use App\Tickets;
use App\Departments;
use App\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Input;
use App\Files;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Redirect;
use App\Http\Controllers\Controller;
use App\TicketUser;
use Illuminate\Support\Facades\Validator;

class TicketsController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }



    public function adminTickets(){
        $users = User::all();
        $tickets = Tickets::where('assigned_to', Auth::id())->orWhere('user_id', Auth::id())->orderBy('created_at', 'desc')->paginate(10);

        $open = Tickets::where(['assigned_to'=> Auth::id(), 'status' => 'ouverte'])->count() + Tickets::where(['user_id'=> Auth::id(), 'status' => 'ouverte'])->count();
        $replied = Tickets::where(['assigned_to'=> Auth::id(), 'replayed' => 1])->count() + Tickets::where(['user_id'=> Auth::id(), 'replayed' => 1])->count();
        $closed = Tickets::where(['assigned_to'=> Auth::id(), 'status' => 'terminée'])->count() + Tickets::where(['user_id'=> Auth::id(), 'status' => 'terminée'])->count();
        $pending = Tickets::where(['assigned_to'=> Auth::id(), 'status' => 'en cours'])->count() + Tickets::where(['user_id'=> Auth::id(), 'status' => 'en cours'])->count();

        $departments = Departments::all();
        $tickets_depart = Tickets::where('assigned_to', Auth::id())->orWhere('user_id', Auth::id())->get();
        return view('admin.tickets.index', compact('tickets', 'open','replied', 'closed', 'pending', 'departments', 'tickets_depart', 'users'));
    }

    public function adminTicketsByUser($id){
        $user = User::find($id);
        if ($user) {
            $tickets = Tickets::where('assigned_to', $user->id)->where('user_id', Auth::id())->orderBy('created_at', 'desc')->paginate(10);
        }else{
            return redirect::to('admin/tickets');
        }
        $userid = $user->id;
        $users = User::all();

        $open = Tickets::where(['assigned_to'=> Auth::id(), 'status' => 'ouverte'])->count() + Tickets::where(['user_id'=> Auth::id(), 'status' => 'ouverte'])->count();
        $replied = Tickets::where(['assigned_to'=> Auth::id(), 'replayed' => 1])->count() + Tickets::where(['user_id'=> Auth::id(), 'replayed' => 1])->count();
        $closed = Tickets::where(['assigned_to'=> Auth::id(), 'status' => 'terminée'])->count() + Tickets::where(['user_id'=> Auth::id(), 'status' => 'terminée'])->count();
        $pending = Tickets::where(['assigned_to'=> Auth::id(), 'status' => 'en cours'])->count() + Tickets::where(['user_id'=> Auth::id(), 'status' => 'en cours'])->count();

        $departments = Departments::all();
        $tickets_depart = Tickets::where('assigned_to', Auth::id())->orWhere('user_id', Auth::id())->get();
        return view('admin.tickets.index', compact('tickets', 'open','replied', 'closed', 'pending', 'departments', 'tickets_depart', 'users', 'userid'));
    }

    //Liées filter By user 
    public function adminTicketsLieesByUser($id){
        $user = User::find($id);
        if ($user) {
            $tickets = Tickets::join('ticket_users', 'ticket_users.ticket_id', '=', 'tickets.id')
            ->join('users', 'users.id', '=', 'ticket_users.user_id')
            ->where('ticket_users.user_id', Auth::id())
            ->where('tickets.assigned_to', $user->id)
            ->orderBy('created_at', 'desc')
            ->select( 'tickets.*')
            ->paginate(10);
            
        }else{
            return redirect::to('admin/tickets');
        }
        $userid = $user->id;
        $liees = true;

        $users = User::all();
        $open = Tickets::join('ticket_users', 'ticket_users.ticket_id', '=', 'tickets.id')
            ->join('users', 'users.id', '=', 'ticket_users.user_id')
            ->where('ticket_users.user_id', Auth::id())->where(['status' => 'ouverte'])->count();
        $replied = Tickets::join('ticket_users', 'ticket_users.ticket_id', '=', 'tickets.id')
            ->join('users', 'users.id', '=', 'ticket_users.user_id')
            ->where('ticket_users.user_id', Auth::id())->where(['replayed' => 1])->count();
        $closed = Tickets::join('ticket_users', 'ticket_users.ticket_id', '=', 'tickets.id')
            ->join('users', 'users.id', '=', 'ticket_users.user_id')
            ->where('ticket_users.user_id', Auth::id())->where(['status' => 'terminée'])->count();
        $pending = Tickets::join('ticket_users', 'ticket_users.ticket_id', '=', 'tickets.id')
            ->join('users', 'users.id', '=', 'ticket_users.user_id')
            ->where('ticket_users.user_id', Auth::id())->where('status', 'en cours')->count();

        $departments = Departments::all();
        $tickets_depart = Tickets::join('ticket_users', 'ticket_users.ticket_id', '=', 'tickets.id')
            ->join('users', 'users.id', '=', 'ticket_users.user_id')
            ->where('ticket_users.user_id', Auth::id())->get();


        return view('admin.tickets.index', compact('tickets', 'open','replied', 'closed', 'pending', 'departments', 'tickets_depart', 'users', 'userid', 'liees'));
    }
    //Liées 
    public function adminTicketsLiees(){
        $liees = true;
        $tickets = Tickets::join('ticket_users', 'ticket_users.ticket_id', '=', 'tickets.id')
        ->join('users', 'users.id', '=', 'ticket_users.user_id')
        ->where('ticket_users.user_id', Auth::id())
        ->orderBy('created_at', 'desc')
        ->select( 'tickets.*')
        ->paginate(10);
        $users = User::all();
        //$tickets = Tickets::where('assigned_to', Auth::id())->orWhere('user_id', Auth::id())->orderBy('created_at', 'desc');


        $open = Tickets::join('ticket_users', 'ticket_users.ticket_id', '=', 'tickets.id')
            ->join('users', 'users.id', '=', 'ticket_users.user_id')
            ->where('ticket_users.user_id', Auth::id())->where(['status' => 'ouverte'])->count();
        $replied = Tickets::join('ticket_users', 'ticket_users.ticket_id', '=', 'tickets.id')
            ->join('users', 'users.id', '=', 'ticket_users.user_id')
            ->where('ticket_users.user_id', Auth::id())->where(['replayed' => 1])->count();
        $closed = Tickets::join('ticket_users', 'ticket_users.ticket_id', '=', 'tickets.id')
            ->join('users', 'users.id', '=', 'ticket_users.user_id')
            ->where('ticket_users.user_id', Auth::id())->where(['status' => 'terminée'])->count();
        $pending = Tickets::join('ticket_users', 'ticket_users.ticket_id', '=', 'tickets.id')
            ->join('users', 'users.id', '=', 'ticket_users.user_id')
            ->where('ticket_users.user_id', Auth::id())->where('status', 'en cours')->count();

        $departments = Departments::all();
        $tickets_depart = Tickets::join('ticket_users', 'ticket_users.ticket_id', '=', 'tickets.id')
            ->join('users', 'users.id', '=', 'ticket_users.user_id')
            ->where('ticket_users.user_id', Auth::id())->get();
        return view('admin.tickets.index', compact('tickets', 'open','replied', 'closed', 'pending', 'departments', 'tickets_depart', 'users', 'liees'));
    }

    public function create(){
        
        $staff = [];
        $users_list = User::all();
        $staff = $users_list;
        $users = User::all();
        
        $departments = Departments::all();
        return view('admin.tickets.new_ticket', compact('departments', 'staff', 'users'));
    }

    public function store(Request $request){
        $this->validate($request, [
            'assign' => 'required',
            'subject' => 'required|min:2|max:300',
            'description' => 'required|min:2|max:10000',
            'file' =>'mimes:jpg,jpeg,png,doc,csv,xlsx,xls,docx,ppt,odt,ods,odp,txt,pdf|max:5120'
        ]);
        $ticket = new Tickets();
        $ticket->assigned_to = $request->assign;
        $ticket->user_id = Auth::id();
        $ticket->token_no = rand(1000, 10000);
        $ticket->subject = $request->subject;
        $ticket->description = $request->description;
        $ticket->status = 'ouverte';
        $ticket->save();
        if($request->data != null){
            foreach ($request->data as $value) {                
                $ticketUser = new TicketUser();
                $ticketUser->user_id = $value;
                $ticketUser->ticket_id = $ticket->id;
                $ticketUser->save();
            }
        }

        if (Input::hasFile('file')) {
            $files = new Files();
            $files->name = $request->file->getClientOriginalName();
            $files->user_id = (Auth::user()) ? Auth::id() : null;
            $files->ticket_id =  $ticket->id;
            $files->reply_id =  0;
            $files->save();
            Storage::putFileAs('', $request->file, $request->file->getClientOriginalName());
        }

        $title = $request->subject;
        $ticket_id = $ticket->id;
        $user_name = Auth::user()->name;

        if(!empty($ticket->assigned_to)){
            $user = User::find($ticket->assigned_to);
            $user->notify(new NewTicket($title, $user_name, $ticket_id));

            $settings = Settings::all()->first();
            //if($settings->ticket_email == 'yes'){
            if(filter_var(trim($user->email), FILTER_VALIDATE_EMAIL)) {
                Mail::send('mails.thanks',['ticket'=>$request], function ($message) use ($user, $ticket, $settings){
                    $message->from('communeurbaine21@gmail.com', 'Nouvelle tâche créée');
                    $message->subject($ticket->subject);
                    $message->to( trim($user->email) , $user->name);
                });
            }
        }
        return redirect::to('admin/tickets')->withMessage("tâche ajoutée");
    }


    public function editTickets($id){
        $user = User::find(Auth::id());
        $staff = [];
        $users_list = User::all();
        $staff = $users_list;
        $users = User::all();
        $ticketUser = TicketUser::select('user_id')->where('ticket_id', $id)->get()->pluck('user_id')->toArray();
        $departments = Departments::all();
        if($user->hasRole('admin')){
            $ticket = Tickets::find($id);
            if(count($ticket)){
                $files = Files::where('ticket_id', $ticket->id)->get();
                return view('admin.tickets.edit_ticket', compact('ticket', 'files', 'departments', 'staff', 'users', 'ticketUser'));
            }else
                return redirect::to('admin/tickets');

        }else{
            $ticket = Tickets::where(['user_id'=> Auth::id(), 'id' => $id])->first();
            if(count($ticket)){
                $files = Files::where('ticket_id', $ticket->id)->get();
                return view('admin.tickets.edit_ticket', compact('ticket', 'files', 'departments', 'staff', 'users', 'ticketUser'));
            }else
                return redirect::to('admin/tickets');
        }
    }

    public function ticketDetail($id){
        $user = User::find(Auth::id());
        $staff = [];
        $users_list = User::all();
        $staff = $users_list;
        $ticketUser = TicketUser::where('ticket_id', $id)->get();
        //dd($ticketUser[0]->user->name);
                
        $ticket = Tickets::where('id', $id)->where(function($query){
            $query->where('assigned_to', Auth::id())->orWhere('user_id', Auth::id());
        })->first();

        if(count($ticket) == 0){
            $ticket = Tickets::join('ticket_users', 'ticket_users.ticket_id', '=', 'tickets.id')
            ->join('users', 'users.id', '=', 'ticket_users.user_id')
            ->where('ticket_users.user_id', Auth::id())
            ->where('tickets.id', $id)
            ->orderBy('created_at', 'desc')
            ->select( 'tickets.*')
            ->first();
        }

        if(count($ticket)){
            $replies = Replies::where('ticket_id', $ticket->id)->get();
            $files = Files::where('ticket_id', $ticket->id)->get();
            return view('admin.tickets.details', compact('ticket', 'replies', 'files', 'staff', 'ticketUser'));
        }else
            return redirect::to('admin/tickets');
        
    }

    public function updateTickets(Request $request, $id){
        $ticket = Tickets::where('id', $id)->where(function($query){
            $query->where('assigned_to', Auth::id())->orWhere('user_id', Auth::id());
        })->first();
        if(count($ticket) == 0)
            return redirect::to('admin/tickets');

        $this->validate($request, [
            'subject' => 'required|max:300',
            'description' => 'required|max:10000'
        ]);

        $ticket->subject = $request->subject;
        $ticket->description = $request->description;
        $ticket->save();
        
        TicketUser::where('ticket_id', $ticket->id)->delete();
        if($request->data != null){
            foreach ($request->data as $value) {                
                $ticketUser = new TicketUser();
                $ticketUser->user_id = $value;
                $ticketUser->ticket_id = $ticket->id;
                $ticketUser->save();
            }
        }
        return redirect()->back()->withMessage('Mise à jour réussie');
    }

    public function deleteTickets($id){
        $ticket = Tickets::where('id', $id)->where(function($query){
            $query->where('assigned_to', Auth::id())->orWhere('user_id', Auth::id());
        })->first();
        if(count($ticket) == 0)
            return redirect::to('admin/tickets');
        
        $files = Files::where('ticket_id', $ticket->id)->get();
        foreach ($files as $file){
            Storage::delete($file->name);
        }
        Files::where('ticket_id', $ticket->id)->delete();
        Replies::where('ticket_id', $ticket->id)->delete();
        TicketUser::where('ticket_id', $ticket->id)->delete();
        Tickets::find($id)->delete();
        return 'success';
    }


    public function addReply(Request $request){

        $ticket = Tickets::where('id', $request->ticket_id)->where(function($query){
            $query->where('assigned_to', Auth::id())->orWhere('user_id', Auth::id());
        })->first();

        if(count($ticket) == 0){
            $ticket = Tickets::join('ticket_users', 'ticket_users.ticket_id', '=', 'tickets.id')
            ->join('users', 'users.id', '=', 'ticket_users.user_id')
            ->where('ticket_users.user_id', Auth::id())
            ->where('tickets.id', $request->ticket_id)
            ->orderBy('created_at', 'desc')
            ->select( 'tickets.*')
            ->first();
        }

        if(count($ticket) == 0)
            return response()->json( '😒', 301);
        
        $validator = Validator::make($request->all(), [
            'file' =>'mimes:jpg,jpeg,png,doc,csv,xlsx,xls,docx,ppt,odt,ods,odp,txt,pdf|max:5120'
        ]);
        if ($validator->fails()) {
            return response( $validator->errors(), 301)
                  ->header('Content-Type', 'application/json');
        }
        $reply = new Replies();
        $reply->reply = $request->reply;
        $reply->ticket_id = $request->ticket_id;
        $reply->user_id = Auth::id();
        $reply->save();

        $title = $ticket->subject;
        $ticket_id =$request->ticket_id;
        $reply_user = Auth::user()->name;
        $ticket->replayed = 1;

        if(!empty($ticket->assigned_to)){
            $user2 = User::find($ticket->assigned_to);
            $user2->notify(new TicketReply($title, $reply_user, $ticket_id));
        }


        $ticket->save();


        $user_image = '';
        if(Auth::user()->avatar ==  null){
            $user_image = '<img src="'.asset('uploads/avatar.png').'" alt="avatar" class="img-circle">';
        }else{
            $user_image = '<img src="'.asset('uploads').'/'.Auth::user()->avatar.'" alt="avatar" class="img-circle">';
        }

        $output = '';

        if (Input::hasFile('file'))
        {
            $file = new Files();
            $file->name = Input::file('file')->getClientOriginalName();
            $file->user_id = Auth::id();
            $file->ticket_id =  $request->ticket_id;
            $file->reply_id =  $reply->id;
            $file->save();
            Storage::putFileAs('', $request->file, $request->file->getClientOriginalName());

            $output = '
                        <div class="ticket-detail-box">
                            <div class="outer-white"  id="'.$reply->id.'">
                                <h3 class="title">
                                '.$user_image.'
                                '.Auth::user()->name.' |
                                <span class="text-muted date">Date: '. $reply->created_at->format('d-m-Y').'</span>
                                 <span class="text-muted time">
                                 @ '.$reply->created_at->format('H:i').'
                                </span>

                                <a href="javascript:;"  class="basic-button delete-btn red pull-right" data-id="'.$reply->id.'">
                                 <i class="fa fa-trash"></i>
                                  </a>


                                </h3>
                                <p class="details">
                                    '.$request->reply.'
                                </p>
                                <p class="file_link">
                                    Attached File:
                                        <a href="'.url('download').'/'.$file->name.'">
                                            <i class="fa fa-paperclip"></i> '.$file->name.'
                                        </a>
                                </p>
                            </div>
                        </div>';
            return $output;
        }else{

            $output = '
                        <div class="ticket-detail-box">
                            <div class="outer-white" id="'.$reply->id.'">
                                <h3 class="title">
                                 '.$user_image.'
                                '.Auth::user()->name.' |
                                <span class="text-muted date">Date: '. $reply->created_at->format('d-m-Y').'</span>
                                 <span class="text-muted time">
                                 @ '.$reply->created_at->format('H:i').'
                                </span>
                                 <a href="javascript:;"  class="basic-button delete-btn red pull-right" data-id="'.$reply->id.'">
                                 <i class="fa fa-trash"></i>
                                  </a>
                                </h3>
                                <p class="details">
                                 '.$request->reply.'
                                  </p>
                            </div>
                        </div>';
            return $output;
        }
    }

    public function deleteReplies($id) {
        $reply = Replies::where(['id' => $id, 'user_id' => Auth::id()])->first();
        $ticket = Tickets::where('id', $reply->ticket_id)->first();      

        $files = Files::where(['reply_id' => $id, 'user_id' => Auth::id()])->get();
        foreach ($files as $file){
            Storage::delete($file->name);
        }
        Files::where(['reply_id' => $id, 'user_id' => Auth::id()])->delete();
        Replies::where(['id' => $id, 'user_id' => Auth::id()])->delete();  
        $replyCount = Replies::where('ticket_id', $ticket->id)->count();
        if($replyCount <= 0){
            $ticket->replayed = 0;
            $ticket->save();
        }

        return 'success';
    }


    public function updateStatus(Request $request, $id){
        $tickets = Tickets::where('id', $id)->where(function($query){
            $query->where('assigned_to', Auth::id())->orWhere('user_id', Auth::id());
        })->first();
        if(count($tickets) == 0)
            return response()->json( '😒', 301);
        
        $tickets->status = $request->status ;
        $tickets->save();

        $title = $tickets->subject;
        $ticket_id = $tickets->id;
        $status = $request->status;
        
        if(Auth::id() != $tickets->user_id){
            $user = User::find($tickets->user_id);
            $user->notify(new TicketStatus($title, $status, $ticket_id));
        }elseif(!empty($tickets->assigned_to)){
            $user = User::find($tickets->assigned_to);
            $user->notify(new TicketStatus($title, $status, $ticket_id));
        }
        return redirect()->back();
    }


    public function download($file_name){

        $path = storage_path('app/').$file_name;
        return response()->download($path);
    }

    public function assignTicket(Request $request, $id){
        $ticket = Tickets::where('id', $id)->where(function($query){
            $query->where('assigned_to', Auth::id())->orWhere('user_id', Auth::id());
        })->first();
        if(count($ticket) == 0)
            return redirect::to('admin/tickets');
        
        $ticket->assigned_to = $request->assign;
        $ticket->save();
        $title = $ticket->subject;
        $ticket_id = $ticket->id;
        $user_name = Auth::user()->name;
        if(!empty($ticket->assigned_to)){
            $user = User::find($ticket->assigned_to);
            $user->notify(new NewTicket($title, $user_name, $ticket_id));
        }
        return redirect()->back();

    }



}
