<?php

namespace App\Http\Controllers;

if (version_compare(PHP_VERSION, '7.2.0', '>=')) {
    // Ignores notices and reports all other kinds... and warnings
    error_reporting(E_ALL ^ E_NOTICE ^ E_WARNING);
    // error_reporting(E_ALL ^ E_WARNING); // Maybe this is enough
}

use App\Notifications\NewTicket;
use App\Notifications\TickReplyet;
use App\Notifications\TicketStatus;
use App\Replies;
use App\Settings;
use App\Tickets;
use App\Departments;
use App\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Input;
use App\Files;
use App\Notifications\TicketReply;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;

class TicketsController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function index(){
        //dd(1);
        
            $tickets = Tickets::where(['assigned_to' => Auth::id()])->paginate(15);
            $open = Tickets::where(['assigned_to' => Auth::id(), 'status'=> 'ouverte'])->count();
            $replied = Tickets::where(['assigned_to' => Auth::id(), 'replayed'=> 1])->count();
            $closed = Tickets::where(['assigned_to' => Auth::id(), 'status'=> 'terminée'])->count();
            $pending = Tickets::where(['assigned_to' => Auth::id(), 'status'=> 'en cours'])->count();
            $departments = Departments::all();
            $tickets_depart = Tickets::where('assigned_to', Auth::id())->get();

            return view('tickets.index', compact('tickets', 'open','replied', 'closed', 'pending', 'departments', 'tickets_depart'));

        

    }
   
    public function ticketDetail($id){
        $user = User::find(Auth::id());
        $staff = [];
        $users_list = User::all();
        foreach ($users_list as $item){
            if($item->hasRole('staff')){
                $staff[] = $item;
            }
        }
        $ticket = Tickets::where(['assigned_to'=> Auth::id(), 'id' => $id])->first();
        if(count($ticket)){
            $replies = Replies::where('ticket_id', $ticket->id)->get();
            $files = Files::where('ticket_id', $ticket->id)->get();
            return view('tickets.details', compact('ticket', 'replies', 'files', 'staff'));
        }else
            return redirect::to('tickets');
        
    }


    public function addReply(Request $request){
        $validator = Validator::make($request->all(), [
            'file' =>'mimes:jpg,jpeg,png,doc,csv,xlsx,xls,docx,ppt,odt,ods,odp,txt,pdf|max:5120'
        ]);
        if ($validator->fails()) {
            return response( $validator->errors(), 301)
                  ->header('Content-Type', 'application/json');
        }
        $reply = new Replies();
        $reply->reply = $request->reply;
        $reply->ticket_id = $request->ticket_id;
        $reply->user_id = Auth::id();
        $reply->save();
        $ticket = Tickets::find($request->ticket_id);

        $title = $ticket->subject;
        $ticket_id =$request->ticket_id;
        $reply_user = Auth::user()->name;
        
        
        $user = User::find($ticket->user_id);
        $user->notify(new TicketReply($title, $reply_user, $ticket_id));
        




        $user_image = '';
        if(Auth::user()->avatar ==  null){
            $user_image = '<img src="'.asset('uploads/avatar.png').'" alt="avatar" class="img-circle">';
        }else{
            $user_image = '<img src="'.asset('uploads').'/'.Auth::user()->avatar.'" alt="avatar" class="img-circle">';
        }

        $output = '';

        if (Input::hasFile('file'))
        {
            $file = new Files();
            $file->name = Input::file('file')->getClientOriginalName();
            $file->user_id = Auth::id();
            $file->ticket_id =  $request->ticket_id;
            $file->reply_id =  $reply->id;
            $file->save();
            Storage::putFileAs('', $request->file, $request->file->getClientOriginalName());

            $output = '
                        <div class="ticket-detail-box">
                            <div class="outer-white"  id="'.$reply->id.'">
                                <h3 class="title">
                                '.$user_image.'
                                '.Auth::user()->name.' |
                                <span class="text-muted date">Date: '. $reply->created_at->format('d-m-Y').'</span>
                                 <span class="text-muted time">
                                 @ '.$reply->created_at->format('H:i').'
                                </span>

                                <a href="javascript:;"  class="basic-button delete-btn red pull-right" data-id="'.$reply->id.'">
                                 <i class="fa fa-trash"></i>
                                  </a>


                                </h3>
                                <p class="details">
                                    '.$request->reply.'
                                </p>
                                <p class="file_link">
                                    Attached File:
                                        <a href="'.url('download').'/'.$file->name.'">
                                            <i class="fa fa-paperclip"></i> '.$file->name.'
                                        </a>
                                </p>
                            </div>
                        </div>';
            return $output;
        }else{

            $output = '
                        <div class="ticket-detail-box">
                            <div class="outer-white" id="'.$reply->id.'">
                                <h3 class="title">
                                 '.$user_image.'
                                '.Auth::user()->name.' |
                                <span class="text-muted date">Date: '. $reply->created_at->format('d-m-Y').'</span>
                                 <span class="text-muted time">
                                 @ '.$reply->created_at->format('H:i').'
                                </span>
                                 <a href="javascript:;"  class="basic-button delete-btn red pull-right" data-id="'.$reply->id.'">
                                 <i class="fa fa-trash"></i>
                                  </a>
                                </h3>
                                <p class="details">
                                 '.$request->reply.'
                                  </p>
                            </div>
                        </div>';
            return $output;
        }
    }

    public function deleteReplies($id) {
        $files = Files::where(['reply_id' => $id, 'user_id' => Auth::id()])->get();
        foreach ($files as $file){
            Storage::delete($file->name);
        }
        Files::where(['reply_id' => $id, 'user_id' => Auth::id()])->delete();
        Replies::where(['id' => $id, 'user_id' => Auth::id()])->delete();
        return 'success';
    }


    public function updateStatus(Request $request, $id){
        $tickets = Tickets::find($id);
        $tickets->status = $request->status ;
        $tickets->save();

        $title = $tickets->subject;
        $ticket_id = $tickets->id;
        $status = $request->status;
        $user = User::find($tickets->user_id);
        $user->notify(new TicketStatus($title, $status, $ticket_id));
        return redirect()->back();
    }


    public function download($file_name){

        $path = storage_path('app/').$file_name;
        return response()->download($path);
    }



}
