@extends('layouts.app')

@section('title', 'Tâches')

@section('content')

    <section id="main-home">
        <div class="main-home">
            <div class="main-img-area app">
                <div class="container">
                    <h1>Liste des tâches</h1>
                    @role('staff')
                    <p>Le tableau contient toutes les tâches qui vous ont été attribuées ou les tâches que vous avez soumises</p>
                    @endrole
                </div>
            </div>
        </div>
    </section>

    <div class="page-content">
        <section id="category-one">
            <div class="category-one">
                <div class="container">
                    <div class="row">
                        <div class="col-md-9 col-sm-12">
                            <div class="table-section">
                                <h3 class="title clearfix">Liste des tâches</h3>
                                <div class="table-responsive">
                                    <table class="table table-lead ticket-table">
                                        <thead>
                                        <tr>
                                            <th class="heading">#</th>
                                            <th class="heading">Sujet</th>
                                            @role('staff')
                                            <th class="heading">Envoyé par</th>
                                            @endrole
                                            <th class="heading">Statut</th>
                                            <th class="heading">Date</th>
                                            <th class="heading">Action</th>
                                        </tr>
                                        </thead>
                                        <tbody>

                                        @foreach($tickets as $ticket)
                                            @if($ticket->user_id == Auth::id() || $ticket->assigned_to == Auth::id())
                                                <tr id="{{$ticket->id}}">
                                                    <td>{{$ticket->token_no}}</td>
                                                    <td>
                                                        <a href="{{url('ticket')}}/{{$ticket->id}}/{{str_replace(' ', '-',   strtolower($ticket->subject) )}}">{{$ticket->subject}}</a></td>
                                                    @role('staff')
                                                    @if($ticket->user_id == Auth::id())
                                                        <td>Moi</td>
                                                    @else
                                                        <td>{{$ticket->submittedBy->name}}</td>
                                                    @endif
                                                    @endrole
                                        
                                                    <td>
                                                    <span class="ticket-status {{$ticket->status}}">
                                                        {{$ticket->status}}
                                                    </span>
                                                    </td>

                                                    <td><a style="color: #6c757d;" data-toggle="tooltip" data-placement="top" title="{{ ($ticket->status == 'terminée')?'terminée':((new DateTime($ticket->created_at))->diff(new DateTime())->format("%a") . ' jours') }}">{{ date('d-m-Y', strtotime($ticket->created_at ?? ''->Fecha)) }}</a></td>
                                                    <td>
                                                        <a href="{{url('ticket')}}/{{$ticket->id}}/{{str_replace(' ', '-',   strtolower($ticket->subject) )}}" class="eye" data-id="{{$ticket->id}}">
                                                            <i class="fa fa-eye"></i>
                                                        </a>
                                                    </td>
                                                </tr>
                                            @endif
                                        @endforeach

                                        </tbody>
                                    </table>
                                </div>
                            </div> 
                            
                            <div class="pagination_links clearfix">
                                {{ $tickets->links() }}
                            </div>
                        </div>
                        <div class="col-md-3">
                            <div class="second-heading-area">
                                <div class="search_box clearfix">
                                    <form action="{{url('find/ticket')}}" method="get">
                                        @if(!empty($search_term))
                                            <input type="text" name="q" class="form-control" placeholder="Recherche..." required value="{{$search_term}}">
                                        @else
                                            <input type="text" name="q" class="form-control" placeholder="Recherche..." required>
                                        @endif
                                        <button type="submit" class="basic-button">Rechercher</button>
                                    </form>
                                </div>
                                <div class="ticket-info">
                                    <div class="title-sidebar">
                                        <h1>Rechercher par statut</h1>
                                    </div>
                                    <div class="catege-one">
                                        <ul>
                                            <li>
                                                <a href="{{url('find/status/ouverte')}}" class="open">
                                                    Tâches ouvertes
                                                    <span class="number-box">{{$open}}</span>
                                                </a>
                                            </li>
                                            <li>
                                                <a href="{{url('find/status/terminée')}}" class="closed">
                                                    Tâches fermées
                                                    <span class="number-box"> {{$closed}}</span>
                                                </a>
                                            </li>
                                            <li>
                                                <a href="{{url('find/status/en cours')}}" class="pending">
                                                    Tâches en cours
                                                    <span class="number-box">{{$pending}}</span>
                                                </a>
                                            </li>
                                            <li>
                                                <a href="{{url('find/status/a répondu')}}" class="replied">
                                                    Tâches répondues
                                                    <span class="number-box">{{$replied}}</span>
                                                </a>
                                            </li>

                                            <li>
                                                <a href="{{url('tickets')}}">
                                                    Toutes les tâches
                                                    <span class="number-box">{{count($tickets_depart)}}</span>
                                                </a>
                                            </li>
                                        </ul>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
    </div>
@stop

@section('script')
    <script>
        $(document).ready(function () {
            $(function () {
                $('[data-toggle="tooltip"]').tooltip()
            });
            $('.navbar-default .navbar-nav li').removeClass('active');
            $('.navbar-default .navbar-nav li.ticket').addClass('active');
            $(".delete-btn").on('click', function () {
                var id = $(this).attr('data-id');
                swal({
                            title: "Êtes-vous sûr?",
                            type: "warning",
                            showCancelButton: true,
                            confirmButtonColor: "#DD6B55",
                            confirmButtonText: "Oui, supprimez-le!",
                            cancelButtonText: "Non, annuler!",
                            closeOnConfirm: false,
                            closeOnCancel: true
                        },
                        function(isConfirm){
                            if (isConfirm) {
                                $.ajax({
                                    type: 'POST',
                                    url: '{{url('/delete/tickets')}}'+"/"+id,
                                    data:{
                                        id:id,
                                        '_token': '{{csrf_token()}}'
                                    },
                                    success: function (data) {
                                        $('.ticket-table tr#'+id+'').hide();
                                        swal("Supprimé!", "Supprimé avec succès.", "success");

                                    }
                                })
                            } else {
                                swal("Cancelled", "Record is safe :)", "error");
                            }
                        });
            });
        });
    </script>
@stop

