<?php

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/


Route::get('/', function() {
    if(optional(Auth::user())->hasRole('admin') or optional(Auth::user())->hasRole('vice-president')){
        return redirect('/admin/tickets');
    }elseif(optional(Auth::user())->hasRole('staff')){
        return redirect('/tickets');
    }else{
        return redirect('/login');
    }
})->name('home');

//Auth::routes();

Route::group(['middleware' => ['role:admin|vice-president']], function() {
    Route::resource('admin/departments', 'Admin\DepartmentsController');

    Route::get('/admin/tickets','Admin\TicketsController@adminTickets')->name('adminTicket');
    Route::get('/admin/tickets/user/{id}','Admin\TicketsController@adminTicketsByUser')->name('adminTicketByUser');
    Route::get('/admin/tickets/liees/user/{id}','Admin\TicketsController@adminTicketsLieesByUser')->name('adminTicketsLieesByUser');
    Route::get('/admin/tickets/liees','Admin\TicketsController@adminTicketsLiees')->name('adminTicketsLiees');
    Route::post('/admin/tickets', 'Admin\TicketsController@store');
    Route::get('/admin/ticket/{id}/{title}','Admin\TicketsController@ticketDetail');
    Route::get('/admin/edit/tickets/{id}', 'Admin\TicketsController@editTickets');
    Route::get('/admin/new/ticket', 'Admin\TicketsController@create');
    Route::post('/admin/update/tickets/{id}','Admin\TicketsController@updateTickets');
    Route::post('/admin/delete/tickets/{id}','Admin\TicketsController@deleteTickets');
    Route::post('/admin/delete/replies/{id}','Admin\TicketsController@deleteReplies');
    Route::post('/admin/update/status/{id}','Admin\TicketsController@updateStatus');
    Route::post('/admin/add-reply','Admin\TicketsController@addReply');
    Route::post('/admin/assign/ticket/{id}','Admin\TicketsController@assignTicket');
    


    Route::resource('admin/staff', 'Admin\StaffController');

    /*user routes*/
    Route::get('/all/users', 'Admin\UsersController@viewUsers');
    Route::post('/delete/users/{id}','Admin\UsersController@deleteUsers');
    Route::get('/edit/users/{id}', 'Admin\UsersController@editUsers');
    Route::post('/update/users/{id}','Admin\UsersController@updateUsers');

    Route::get('/admin/search/ticket/','Admin\SearchController@search');
    Route::get('/admin/search/status/{status}','Admin\SearchController@status');
    Route::get('/admin/search/department/{id}','Admin\SearchController@department');
    Route::get('/admin/search/liees/status/{status}','Admin\SearchController@statusLiees');

    /*settings*/
    Route::get('/admin/settings', 'Admin\SettingsController@index');
    Route::post('/admin/settings', 'Admin\SettingsController@update');

    /*User account settings*/
    Route::get('/admin/profile/settings','Admin\ProfileController@profile');
    Route::post('/admin/profile/settings','Admin\ProfileController@updateProfile');
        


    /*change password*/
    Route::get('/admin/change/password','Admin\ProfileController@resetPassword');
    Route::post('/admin/change/password','Admin\ProfileController@updatePassword');

    Route::get('admin/markAsRead', function (){
        Auth::user()->notifications->markAsRead();
    });
});
Route::get('/download/{file_name}','TicketsController@download');
Route::group(['middleware' => ['role:staff']], function() {


    Route::get('/tickets', 'TicketsController@index')->name('tickets');
    Route::post('tickets', 'TicketsController@store');
    Route::get('/ticket/{id}/{title}','TicketsController@ticketDetail');
    Route::get('/edit/tickets/{id}', 'TicketsController@editTickets');
    Route::get('/new/ticket', 'TicketsController@create');
    Route::post('/update/tickets/{id}','TicketsController@updateTickets');
    Route::post('/delete/tickets/{id}','TicketsController@deleteTickets');
    Route::post('/delete/replies/{id}','TicketsController@deleteReplies');
    Route::post('/update/status/{id}','TicketsController@updateStatus');
    Route::post('/add-reply','TicketsController@addReply');
    Route::post('/assign/ticket/{id}','TicketsController@assignTicket');
    


    Route::get('/find/ticket/','FindController@search');
    Route::get('/find/status/{status}','FindController@status');
    Route::get('/find/department/{id}','FindController@department');

    
    /*User account settings*/
    Route::get('profile/settings','ProfileController@profile');
    Route::post('profile/settings','ProfileController@updateProfile');

    
    /*change password*/
    Route::get('change/password','ProfileController@resetPassword');
    Route::post('change/password','ProfileController@updatePassword');

    Route::get('/markAsRead', function (){
        Auth::user()->notifications->markAsRead();
    });
});





Auth::routes([
    'register' => false, // Registration Routes...
    //'reset' => false, // Password Reset Routes...
    //'verify' => false, // Email Verification Routes...
  ]);

Route::any('{catchall}', function() {
    return redirect('/');
})->where('catchall', '.*');
